@@ -28,13 +28,13 @@
 
 #include <kconfiggroup.h>
 
-#include <QtCore/QFile>
-#include <QtCore/QMap>
-#include <QtCore/QTextStream>
-#include <QtCore/QSharedData>
-#include <QtCore/QStandardPaths>
-#include <QtCore/QLocale>
-#include <QtCore/QDataStream>
+#include <QFile>
+#include <QMap>
+#include <QTextStream>
+#include <QSharedData>
+#include <QStandardPaths>
+#include <QLocale>
+#include <QDataStream>
 
 using namespace KContacts;
 
@@ -84,9 +84,7 @@ static int findBalancedBracket(const QString &tsection, int pos)
   @param result     QString reference in which the result will be stored
   @return           true if at least one tag evaluated positively, else false
 */
-static bool parseAddressTemplateSection(const QString &tsection, QString &result,
-                                        const QString &realName, const QString &orgaName,
-                                        const KContacts::Address &address)
+static bool parseAddressTemplateSection(const QString &tsection, QString &result, const QString &realName, const QString &orgaName, const KContacts::Address &address)
 {
     // This method first parses and substitutes any bracketed sections and
     // after that replaces any tags with their values. If a bracketed section
@@ -101,17 +99,16 @@ static bool parseAddressTemplateSection(const QString &tsection, QString &result
     int fpos = result.indexOf(KCONTACTS_FMTTAG_purgeempty, stpos);
     while (-1 != fpos) {
         int bpos1 = fpos + KCONTACTS_FMTTAG_purgeempty.length();
-        int bpos2;
         // expect opening bracket and find next balanced closing bracket. If
         // next char is no opening bracket, continue parsing (no valid tag)
         if (QLatin1Char('(') == result[bpos1]) {
-            bpos2 = findBalancedBracket(result, bpos1);
+            int bpos2 = findBalancedBracket(result, bpos1);
             if (-1 != bpos2) {
                 // we have balanced brackets, recursively parse:
                 QString rplstr;
                 bool purge = !parseAddressTemplateSection(result.mid(bpos1 + 1,
-                             bpos2 - bpos1 - 1), rplstr,
-                             realName, orgaName, address);
+                                                                     bpos2 - bpos1 - 1), rplstr,
+                                                          realName, orgaName, address);
                 if (purge) {
                     // purge -> remove all
                     // replace with !_P_!, so conditional tags work later
@@ -136,11 +133,11 @@ static bool parseAddressTemplateSection(const QString &tsection, QString &result
     // keeping track of whether at least one tag evaluates to something.
     // The following macro needs QString for R_FIELD
     // It substitutes !_P_! for empty fields so conditional tags work later
-#define REPLTAG(R_TAG,R_FIELD) \
-    if ( result.indexOf( R_TAG ) != -1 ) { \
-        QString rpl = R_FIELD.isEmpty() ? QStringLiteral( "!_P_!" ) : R_FIELD; \
-        result.replace( R_TAG, rpl ); \
-        if ( !R_FIELD.isEmpty() ) { \
+#define REPLTAG(R_TAG, R_FIELD) \
+    if (result.contains(R_TAG)) { \
+        QString rpl = R_FIELD.isEmpty() ? QStringLiteral("!_P_!") : R_FIELD; \
+        result.replace(R_TAG, rpl); \
+        if (!R_FIELD.isEmpty()) { \
             ret = true; \
         } \
     }
@@ -177,7 +174,7 @@ static bool parseAddressTemplateSection(const QString &tsection, QString &result
         const QString str1 = result.mid(fpos - 5, 5);
         const QString str2 = result.mid(fpos + 2, 5);
         if (str1 != QLatin1String("!_P_!") && str2 != QLatin1String("!_P_!")) {
-            result.replace(fpos, 2, QStringLiteral(" "));
+            result.replace(fpos, 2, QLatin1Char(' '));
         } else {
             result.remove(fpos, 2);
         }
@@ -195,7 +192,7 @@ class Q_DECL_HIDDEN Address::Private : public QSharedData
 public:
     Private()
         : mEmpty(true)
-        , mType(Q_NULLPTR)
+        , mType(nullptr)
     {
         mId = KRandom::randomString(10);
     }
@@ -543,9 +540,8 @@ QString Address::typeFlagLabel(TypeFlag type)
         return i18nc("Work Address", "Work");
     case Pref:
         return i18n("Preferred Address");
-    default:
-        return i18nc("another type of address", "Other");
     }
+    return i18nc("another type of address", "Other");
 }
 
 void Address::setGeo(const Geo &geo)
@@ -561,9 +557,7 @@ Geo Address::geo() const
 
 QString Address::toString() const
 {
-    QString str;
-
-    str += QLatin1String("Address {\n");
+    QString str = QLatin1String("Address {\n");
     str += QStringLiteral("  IsEmpty: %1\n").
            arg(d->mEmpty ? QStringLiteral("true") : QStringLiteral("false"));
     str += QStringLiteral("  Id: %1\n").arg(d->mId);
@@ -582,8 +576,7 @@ QString Address::toString() const
     return str;
 }
 
-QString Address::formattedAddress(const QString &realName,
-                                  const QString &orgaName) const
+QString Address::formattedAddress(const QString &realName, const QString &orgaName) const
 {
     QString ciso;
     QString addrTemplate;
@@ -624,9 +617,9 @@ QString Address::formattedAddress(const QString &realName,
     // now add the country line if needed (formatting this time according to
     // the rules of our own system country )
     if (!country().isEmpty()) {
-        KConfig entry(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("kf5/locale/countries/") +
-                                             QLocale().name() +
-                                             QLatin1String("/country.desktop")));
+        KConfig entry(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("kf5/locale/countries/")
+                                             +QLocale().name()
+                                             +QLatin1String("/country.desktop")));
         KConfigGroup group = entry.group("KCM Locale");
         QString cpos = group.readEntry("AddressCountryPosition");
         if (QLatin1String("BELOW") == cpos || cpos.isEmpty()) {
@@ -699,8 +692,8 @@ QString Address::ISOtoCountry(const QString &ISOname)
         QTextStream s(&file);
         QString searchStr = QLatin1Char('\t') + ISOname.simplified().toLower();
         QString strbuf = s.readLine();
-        int pos;
         while (!strbuf.isEmpty()) {
+            int pos;
             if ((pos = strbuf.indexOf(searchStr)) != -1) {
                 file.close();
                 return i18n(strbuf.left(pos).toUtf8().constData());
@@ -716,18 +709,18 @@ QString Address::ISOtoCountry(const QString &ISOname)
 QDataStream &KContacts::operator<<(QDataStream &s, const Address &addr)
 {
     return s << addr.d->mId << (uint)addr.d->mType << addr.d->mPostOfficeBox
-           << addr.d->mExtended << addr.d->mStreet << addr.d->mLocality
-           << addr.d->mRegion << addr.d->mPostalCode << addr.d->mCountry
-           << addr.d->mLabel << addr.d->mEmpty << addr.d->mGeo;
+             << addr.d->mExtended << addr.d->mStreet << addr.d->mLocality
+             << addr.d->mRegion << addr.d->mPostalCode << addr.d->mCountry
+             << addr.d->mLabel << addr.d->mEmpty << addr.d->mGeo;
 }
 
 QDataStream &KContacts::operator>>(QDataStream &s, Address &addr)
 {
     uint type;
     s >> addr.d->mId >> type >> addr.d->mPostOfficeBox >> addr.d->mExtended
-      >> addr.d->mStreet >> addr.d->mLocality >> addr.d->mRegion
-      >> addr.d->mPostalCode >> addr.d->mCountry >> addr.d->mLabel
-      >> addr.d->mEmpty >> addr.d->mGeo;
+    >> addr.d->mStreet >> addr.d->mLocality >> addr.d->mRegion
+    >> addr.d->mPostalCode >> addr.d->mCountry >> addr.d->mLabel
+    >> addr.d->mEmpty >> addr.d->mGeo;
 
     addr.d->mType = Address::Type(type);
 
