@@ -25,9 +25,7 @@
 #include <QSharedDataPointer>
 #include <QString>
 
-namespace KContacts
-{
-
+namespace KContacts {
 /**
  * @short Geographic position
  *
